# welco - multichannel request processing
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json

from django import template
from django.core.urlresolvers import reverse_lazy
from django.http import HttpResponse, HttpResponseRedirect
from django.template import RequestContext
from django.views.decorators.csrf import csrf_exempt
from django.views.generic import (DetailView, CreateView, UpdateView,
        ListView, DeleteView, TemplateView)

from haystack.forms import SearchForm
from haystack.generic_views import SearchView
from haystack.query import SearchQuerySet
from reversion.models import Version
from reversion.revisions import default_revision_manager

from .models import Page
from .forms import PageForm


class PageListView(ListView):
    model = Page

    def get_context_data(self, **kwargs):
        context = super(PageListView, self).get_context_data(**kwargs)
        context['form'] = SearchForm()
        return context

page_list = PageListView.as_view()


class PageAddView(CreateView):
    model = Page
    form_class = PageForm

page_add = PageAddView.as_view()


class PageEditView(UpdateView):
    model = Page
    form_class = PageForm

page_edit = PageEditView.as_view()


class PageDetailView(DetailView):
    model = Page

page_detail = PageDetailView.as_view()


class PageDetailFragmentView(DetailView):
    model = Page
    template_name = 'kb/page_detail_fragment.html'

page_detail_fragment = PageDetailFragmentView.as_view()


class PageDeleteView(DeleteView):
    model = Page
    success_url = reverse_lazy('kb-home')

page_delete = PageDeleteView.as_view()


class PageSearchView(SearchView):
    template_name = 'kb/page_search.html'
    form_class = SearchForm

page_search = PageSearchView.as_view()


class PageHistoryView(DetailView):
    model = Page
    template_name = 'kb/page_history.html'

    def get_context_data(self, **kwargs):
        context = super(PageHistoryView, self).get_context_data(**kwargs)
        context['versions_list'] = default_revision_manager.get_for_object(self.get_object())
        return context

page_history = PageHistoryView.as_view()


class PageVersionView(DetailView):
    model = Page
    template_name = 'kb/page_version.html'

    def get_context_data(self, **kwargs):
        context = super(PageVersionView, self).get_context_data(**kwargs)
        context['object'] = Version.objects.get(id=self.kwargs.get('version')).object_version.object
        self.kwargs.get('version')
        return context

    def post(self, request, *args, **kwargs):
        version = Version.objects.get(id=self.kwargs.get('version'))
        version.revision.revert()
        return HttpResponseRedirect(self.get_object().get_absolute_url())

page_version = PageVersionView.as_view()


class KbZone(TemplateView):
    template_name = 'kb/zone.html'

    def get_context_data(self, **kwargs):
        context = super(KbZone, self).get_context_data(**kwargs)
        context['form'] = SearchForm()
        return context

zone = csrf_exempt(KbZone.as_view())


def page_search_json(request):
    query = request.GET.get('q')
    searchqueryset = SearchQuerySet()
    sqs = searchqueryset.autocomplete(text_auto=query)
    sqs.load_all()

    result = []
    for item in sqs:
        result.append({'title': item.title, 'slug': item.slug});

    response = HttpResponse(content_type='application/json')
    json.dump({'data': result}, response, indent=2)
    return response


class HomeZone(object):
    def __init__(self, request):
        self.request = request

    def render(self):
        context = RequestContext(self.request)
        tmpl = template.loader.get_template('kb/zone.html')
        return tmpl.render(context)
